lilypondparsertools.LilyPondDuration
====================================

.. inheritance-diagram:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration
   :private-bases:

.. autoclass:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
